@@ -8,13 +8,12 @@ logger = logging.getLogger()
 logging.getLogger('calcbench').setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler(stream=sys.stdout))
 """
-__version__ = "4.1.0"
+__version__ = "4.2.0"
 from .api_client import (
     CompanyIdentifierScheme,
     as_reported_raw,
     business_combinations,
     company_disclosures,
-    dimensional_raw,
     disclosure_text,
     document_types,
     enable_backoff,
@@ -43,3 +42,13 @@ from .standardized_numeric import (
 from .raw_numeric_XBRL import raw_XBRL, raw_xbrl_raw
 
 from .raw_numeric_non_XBRL import non_XBRL_numeric_raw, non_XBRL_numeric
+
+from .dimensional import (
+    dimensional_raw,
+)
+
+from .business_combinations import (
+    business_combinations_raw,
+    business_combinations,
+    legacy_report as business_combination_legacy_report,
+)
